@@ -43,24 +43,26 @@ jn <- floodlight <- function(model,dv,iv,mod,mrange,alpha =.05, yas='none'){
   if(is(model,'list')){
     if(is.null(model$coefficients)){
       stop("list model does not contain 'coefficients'")
-    }
-    else{
+    } else {
       beta.hat <- model$coefficients
     }
     if(is.null(model$vcov)){
       stop("list model does not contain 'vcov'")
-    } else{
+    } else {
       cov <- model$vcov
     }
-  } else if(is(model,'glm') & (model$family$link == 'log' || model$family$link == 'logit')){
-    beta.hat <- coef(model)
-    cov <- vcov(model)
-    jnret$link <- model$family$link
+  } else if(is(model,'glm')){
+    if(model$family$link == 'log' | model$family$link == 'logit'){
+      beta.hat <- coef(model)
+      cov <- vcov(model)
+      jnret$link <- model$family$link
+    } else {
+      stop('this function currently supports only glm models with link == log or logit')
+    }
   } else if(is(model,'lm')){
     beta.hat <- coef(model)
     cov <- vcov(model)
-  }
-  else{
+  } else{
     stop('this method currently supports only the lm, glm(yas == log or logit) & custom list objects')
   }
 
